<!--
** Please read **

* Do not request features that are specific to your model repository source here.

* Before opening a new issue, make sure to search for keywords in the issues
  list and verify the issue you're about to submit isn't a duplicate:

- internal: https://gitlab.science.gc.ca/CanESM/imsi/-/issues
- external: https://gitlab.com/cccma/imsi/-/issues
-->

## Summary

<!-- Provide a short summary of the feature request here.
- This should summarize the main idea and use-case of the feature.
- Add links to related issues
-->

### Problem to solve

<!-- Describe what this new feature is trying to solve. -->

### Proposal

<!-- Describe the feature in detail and how it will work. -->

<!-- Where appropriate:
- Add relevant diagrams, mock-ups of interfaces, expected output, etc.
- List potential risk factors, if known.
-->

### Importance

<!-- Describe why this feature is important
e.g., how this impacts workflow, how this may improve software functionality, why users might want to use it.
-->

<!-- v OPTIONAL, uncomment title v -->
<!-- ## Implementation Plan -->

<!--
Provide an outline of where in the imsi code base this feature
might live, which classes it may interact with, etc.
-->

<!-- Leave this label, do not add others -->
/label ~"feature"
